@@ -1,4 +1,5 @@
 if (getRversion() >= '2.15.1') globalVariables(c('buttonsFrame', 
  'dcFrame', 'dcVariable', 'distFrame', 'distVariable', 'formulaFrame',
  'methodtypeFrame', 'methodtypeVariable', 'outerOperatorsFrame', 
- 'rhsVariable', 'subsetFrame', 'subsetVariable', 'top', 'xBox'))
+ 'rhsVariable', 'subsetFrame', 'subsetVariable', 'top', 'covariatesBox',
+ 'covariatesFrame'))
